@@ -1,4 +1,4 @@
-"""WARNING: Dont't do anything here - shadowed by loslassy.py.
+"""WARNING: Don't do anything here - shadowed by loslassa.py.
 
 I know that this is a bit naughty, but I want the
 loslassa/loslassa/loslassa mantra to be part of the project structure ;)
